from ..base import AsyncFunctionMixin
from ..vfolder import BaseVFolder

__all__ = (
    'VFolder',
)


class VFolder(AsyncFunctionMixin, BaseVFolder):
    '''
    Deprecated! Use ai.backend.client.AsyncSession instead.
    '''
    pass



from ..base import AsyncFunctionMixin
from ..kernel import BaseKernel

__all__ = (
    'Kernel',
    'AsyncKernel',
)


class Kernel(AsyncFunctionMixin, BaseKernel):
    '''
    Deprecated! Use ai.backend.client.AsyncSession instead.
    '''
    pass


# legacy alias
AsyncKernel = Kernel
